@@ -6,8 +6,8 @@ from bobtemplates.plone.base import get_normalized_classname
 from bobtemplates.plone.base import get_normalized_dxtypename
 from bobtemplates.plone.base import get_normalized_ftiname
 from bobtemplates.plone.base import git_commit
-from bobtemplates.plone.base import is_string_in_file
 from bobtemplates.plone.base import update_file
+from bobtemplates.plone.utils import run_black
 from bobtemplates.plone.utils import run_isort
 from lxml import etree
 from mrbob.bobexceptions import SkipQuestion
@@ -21,15 +21,15 @@ import re
 def is_container(configurator, question):
     """Test if base class is a container."""
     if configurator.variables["dexterity_type_base_class"] != "Container":
-        raise SkipQuestion(u"Is not a Container, so we skip filter question.")
+        raise SkipQuestion("Is not a Container, so we skip filter question.")
 
 
 def supermodel_is_used(configurator, question):
     """Test if supermodel is used."""
     if configurator.variables.get("dexterity_type_supermodel", False):
         raise SkipQuestion(
-            u"Skip question, because we need a base class ",
-            u"when supermodel ist used.",
+            "Skip question, because we need a base class ",
+            "when supermodel ist used.",
         )
 
 
@@ -37,12 +37,12 @@ def check_dexterity_type_name(configurator, question, answer):
     """Test if type name is valid."""
     if keyword.iskeyword(answer):
         raise ValidationError(
-            u'"{key}" is a reserved Python keyword!'.format(key=answer)
+            '"{key}" is a reserved Python keyword!'.format(key=answer)
         )  # NOQA: E501
     if not re.match("[_a-zA-Z ]*$", answer):
         raise ValidationError(
-            u'"{key}" is not a valid identifier!\n'
-            u"Allowed characters: _ a-z A-Z and whitespace.\n".format(
+            '"{key}" is not a valid identifier!\n'
+            "Allowed characters: _ a-z A-Z and whitespace.\n".format(
                 key=answer
             ),  # NOQA: E501
         )
@@ -53,14 +53,14 @@ def check_global_allow(configurator, answer):
     """Skip parent container name if global_allow is true."""
     if configurator.variables.get("dexterity_type_global_allow", False):
         raise SkipQuestion(
-            u"global_allow is true, so we skip parent container name question."
+            "global_allow is true, so we skip parent container name question."
         )  # NOQA: E501
 
 
 def _update_metadata_xml(configurator):
     """Add plone.app.dexterity dependency metadata.xml in Generic Setup profiles."""  # NOQA: E501
-    metadata_file_name = u"metadata.xml"
-    metadata_file_dir = u"profiles/default"
+    metadata_file_name = "metadata.xml"
+    metadata_file_dir = "profiles/default"
     metadata_file_path = (
         configurator.variables["package_folder"]
         + "/"
@@ -76,8 +76,6 @@ def _update_metadata_xml(configurator):
         deps = [
             "profile-plone.app.dexterity:default",
         ]
-        if not configurator.variables["plone.is_plone5"]:
-            deps.append("profile-plone.app.relationfield:default")
         changed = False
         for dep in deps:
             dep_exists = False
@@ -111,8 +109,8 @@ def _update_metadata_xml(configurator):
 
 def _update_types_xml(configurator):
     """Add the new type to types.xml in Generic Setup profiles."""
-    types_file_name = u"types.xml"
-    types_file_dir = u"profiles/default"
+    types_file_name = "types.xml"
+    types_file_dir = "profiles/default"
     types_file_path = (
         configurator.target_directory + "/" + types_file_dir + "/" + types_file_name
     )
@@ -155,7 +153,7 @@ def _update_parent_types_fti_xml(configurator):
     parent_dexterity_type_fti_file_name = get_normalized_ftiname(
         parent_ct_name
     )  # NOQA: E501
-    file_name = u"{0}.xml".format(
+    file_name = "{0}.xml".format(
         parent_dexterity_type_fti_file_name,
     )
     file_path = "{0}/profiles/default/types/{1}".format(
@@ -187,7 +185,7 @@ def _update_parent_types_fti_xml(configurator):
 
 
 def _update_rolemap_xml(configurator):
-    file_name = u"rolemap.xml"
+    file_name = "rolemap.xml"
     file_path = "{0}/profiles/default/{1}".format(
         configurator.variables["package_folder"],
         file_name,
@@ -225,7 +223,7 @@ def _update_rolemap_xml(configurator):
 
 
 def _update_permissions_zcml(configurator):
-    file_name = u"permissions.zcml"
+    file_name = "permissions.zcml"
     file_path = configurator.variables["package_folder"] + "/" + file_name
     nsprefix = "{http://namespaces.zope.org/zope}"
 
@@ -260,22 +258,6 @@ def _update_permissions_zcml(configurator):
     update_file(configurator, file_path, match_str, insert_str)
 
 
-def _update_setup_py(configurator):
-    if configurator.variables["plone.is_plone5"]:
-        return
-    file_name = u"setup.py"
-    file_path = configurator.variables["package.root_folder"] + "/" + file_name
-    match_str = "-*- Extra requirements: -*-"
-    insert_strings = [
-        "plone.app.dexterity",
-    ]
-    for insert_str in insert_strings:
-        insert_str = "        '{0}',\n".format(insert_str)
-        if is_string_in_file(configurator, file_path, insert_str):
-            continue
-        update_file(configurator, file_path, match_str, insert_str)
-
-
 def pre_ask(configurator):
     """Empty pre ask."""
 
@@ -305,8 +287,8 @@ def post_renderer(configurator):
     _update_permissions_zcml(configurator)
     _update_rolemap_xml(configurator)
     _update_metadata_xml(configurator)
-    _update_setup_py(configurator)
     run_isort(configurator)
+    run_black(configurator)
     git_commit(
         configurator,
         "Add content_type: {0}".format(
