@@ -4,6 +4,7 @@ from bobtemplates.plone.base import base_prepare_renderer
 from bobtemplates.plone.base import echo
 from bobtemplates.plone.base import git_commit
 from bobtemplates.plone.base import update_file
+from bobtemplates.plone.utils import run_black
 from bobtemplates.plone.utils import run_isort
 from lxml import etree
 from mrbob.bobexceptions import ValidationError
@@ -15,7 +16,7 @@ import re
 def check_name(configurator, question, answer):
     if not re.match("^[a-z]+-+[a-z0-9]+(-+[a-z0-9]+)*$", answer):
         raise ValidationError(
-            u"{key} is not a valid custom-element identifier. Please try something like this 'my-element'".format(
+            "{key} is not a valid custom-element identifier. Please try something like this 'my-element'".format(
                 key=answer
             )
         )  # NOQA: E501
@@ -23,7 +24,7 @@ def check_name(configurator, question, answer):
 
 
 def _update_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     file_path = configurator.variables["package_folder"] + "/" + file_name
     namespaces = {"plone": "http://namespaces.plone.org/plone"}
 
@@ -69,6 +70,7 @@ def post_renderer(configurator):
     """Post rendering."""
     _update_configure_zcml(configurator)
     run_isort(configurator)
+    run_black(configurator)
     git_commit(
         configurator,
         "Add Svelte app: in svelte_apps/{0}".format(
