@@ -2,6 +2,7 @@
 
 from bobtemplates.plone.base import base_prepare_renderer
 from bobtemplates.plone.base import echo
+from bobtemplates.plone.base import get_normalized_themename
 from bobtemplates.plone.base import git_commit
 from bobtemplates.plone.base import is_string_in_file
 from bobtemplates.plone.base import update_file
@@ -29,13 +30,13 @@ def pre_theme_name(configurator, question):
 
 
 def post_theme_name(configurator, question, answer):
-    regex = r"^\w+[a-zA-Z0-9 \.\-_]*\w$"
+    regex = r"^\w+[a-zA-Z0-9 \.\-_\(\)]*$"
     if not re.match(regex, answer):
-        msg = u"Error: '{0}' is not a valid themename.\n".format(answer)
-        msg += u"Please use a valid name (like 'Tango' or 'my-tango.com')!\n"
-        msg += u"At beginning or end only letters|diggits are allowed.\n"
-        msg += u"Inside the name also '.-_' are allowed.\n"
-        msg += u"No umlauts!"
+        msg = "Error: '{0}' is not a valid themename.\n".format(answer)
+        msg += "Please use a valid name (like 'My Tango' or 'my-tango.com')!\n"
+        msg += "At beginning only letters|diggits are allowed.\n"
+        msg += "Inside the name also '.-_()' are allowed.\n"
+        msg += "No umlauts!"
         raise ValidationError(msg)
     return answer
 
@@ -45,22 +46,17 @@ def prepare_renderer(configurator):
     configurator = base_prepare_renderer(configurator)
     configurator.variables["template_id"] = "theme"
 
-    def normalize_theme_name(value):
-        value = "-".join(value.split("_"))
-        value = "-".join(value.split())
-        return value
-
-    configurator.variables["theme.normalized_name"] = normalize_theme_name(
+    configurator.variables["theme.normalized_name"] = get_normalized_themename(
         configurator.variables.get("theme.name"),
-    ).lower()
+    )
     configurator.target_directory = configurator.variables["package_folder"]
 
 
 def _update_metadata_xml(configurator):
     """Add plone.app.theming dependency metadata.xml in Generic Setup
     profiles."""
-    metadata_file_name = u"metadata.xml"
-    metadata_file_dir = u"profiles/default"
+    metadata_file_name = "metadata.xml"
+    metadata_file_dir = "profiles/default"
     metadata_file_path = (
         configurator.variables["package_folder"]
         + "/"
@@ -101,7 +97,7 @@ def _update_metadata_xml(configurator):
 
 
 def _update_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     file_path = configurator.variables["package_folder"] + "/" + file_name
 
     with open(file_path, "r") as xml_file:
@@ -133,13 +129,11 @@ def _update_configure_zcml(configurator):
 
 
 def _update_setup_py(configurator):
-    file_name = u"setup.py"
+    file_name = "setup.py"
     file_path = configurator.variables["package.root_folder"] + "/" + file_name
     match_str = "-*- Extra requirements: -*-"
     insert_strings = [
-        # 'collective.themesitesetup',  # disable while not ready for Plone 5.2
-        "collective.themefragments",
-        "plone.app.themingplugins",
+        # "plone.app.themingplugins",
     ]
     for insert_str in insert_strings:
         insert_str = "        '{0}',\n".format(insert_str)
@@ -151,7 +145,7 @@ def _update_setup_py(configurator):
 def post_renderer(configurator):
     """"""
     _update_configure_zcml(configurator)
-    _update_setup_py(configurator)
+    # _update_setup_py(configurator)
     _update_metadata_xml(configurator)
     git_commit(
         configurator,
@@ -159,3 +153,12 @@ def post_renderer(configurator):
             configurator.variables["theme.name"],
         ),
     )
+    echo(
+        """\nYour theme was added here: {0}/theme
+Run 'npm install' to get the dependencies
+and then 'npm run watch' to compile the styles.
+""".format(
+            configurator.variables["package_folder"],
+        ),
+        "info",
+    )
