@@ -5,6 +5,7 @@ from bobtemplates.plone.base import echo
 from bobtemplates.plone.base import git_commit
 from bobtemplates.plone.base import update_file
 from bobtemplates.plone.base import ZCML_NAMESPACES
+from bobtemplates.plone.utils import run_black
 from bobtemplates.plone.utils import run_isort
 from lxml import etree
 
@@ -13,7 +14,7 @@ import os
 
 
 def _update_package_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     file_path = configurator.variables["package_folder"] + "/" + file_name
 
     with open(file_path, "r") as xml_file:
@@ -35,7 +36,7 @@ def _update_package_configure_zcml(configurator):
 
 
 def _update_vocabularies_configure_zcml(configurator):
-    file_name = u"configure.zcml"
+    file_name = "configure.zcml"
     file_path = configurator.variables["package_folder"] + "/vocabularies/" + file_name
     example_file_path = file_path + ".example"
     file_list = os.listdir(os.path.dirname(file_path))
@@ -90,6 +91,7 @@ def post_renderer(configurator):
     _update_package_configure_zcml(configurator)
     _update_vocabularies_configure_zcml(configurator)
     run_isort(configurator)
+    run_black(configurator)
     git_commit(
         configurator,
         "Add vocabulary: {0}".format(
