@@ -6,11 +6,11 @@ from mrbob.configurator import Configurator
 
 def test_prepare_renderer():
     configurator = Configurator(
-        template='bobtemplates.plone:buildout',
-        target_directory='collective.foo',
+        template="bobtemplates.plone:buildout",
+        target_directory="collective.foo",
     )
     buildout.prepare_renderer(configurator)
-    assert configurator.variables['template_id'] == 'buildout'
+    assert configurator.variables["template_id"] == "buildout"
 
 
 def test_post_renderer():
